from abc import ABC, abstractmethod


class CoreCheck(): 
    def __init__(self, resource_name, context):
        self.cloud = None
        self.resource = None
        self.resource_name = resource_name
        self.name = None
        self.result = None
        self.message = None
        self.context = context

    @abstractmethod
    def scan(self):
        pass



from ..aws_eks_check import AWSEKSCheck


class ServiceSecretsCheck(AWSEKSCheck):
    def __init__(self, resource_name, context):
        super().__init__(resource_name, context)
        self.name = "service-secrets"

    def scan(self):
        self.result = "PASS"



import argparse
import os
import sys

from core.aws.eks.aws_eks_runner import AWSEKSRunner


def main():
    arg_parser = argparse.ArgumentParser()
    arg_parser.add_argument('--cloud', action='store', type=str, required=True)
    arg_parser.add_argument('--resource', action='store', type=str, required=True)
    arg_parser.add_argument('--name', action='store', type=str, required=True)
    args = arg_parser.parse_args()

    CLOUD = args.cloud
    RESOURCE = args.resource
    NAME = args.name

    print("Sek - Runtime Cloud Security Scanning\n-----")
    print("Cloud: " + CLOUD + " - Resource: " + RESOURCE + " - Name: " + NAME + "\n-----")
    
    if ( CLOUD == "aws" or CLOUD == "AWS" ) and ( RESOURCE == "eks" or RESOURCE == "EKS" ):
        print("Scan\n-----")
        runner = AWSEKSRunner(NAME)
    else:
        print("No Cloud / Resource match. See: https://github.com/njgibbon/sek/tree/main/checks")
        sys.exit(1)

    print(runner.format_results(), end = "")
    print("-----")
    print("Check Document: " + runner.link)
    print("-----")
    print("Stats")
    print("-----")
    print(runner.format_stats())

    stats = runner.stats()
    if stats["checks"] != stats["passed"]:
        sys.exit(1)


if __name__ == '__main__':
    main()



import boto3

from ...core_context import CoreContext


class AWSEKSContext(CoreContext):
    eks_client = boto3.client("eks")
    ec2_client = boto3.client("ec2")

    def __init__(self, name):
        super().__init__(name)
        self.cloud = "aws"
        self.resource = "eks"
        self.new = "new"
        self.frog = "bababa"
        # self.cluster_description = self.eks_client.describe_cluster(name=name)




class CoreRunner():
    def __init__(self, name):
        self.cloud = None
        self.resource = None
        self.link = None
        self.name = name
        self.context = None
        self.checks = []

    def scan(self):
        for check in self.checks:
            check.scan()

    def results(self):
        result_list = []
        for check in self.checks:
            result_map = {}
            result_map["name"] = check.name
            result_map["result"] = check.result
            result_map["message"] = check.message
            result_list.append(result_map)
        return result_list

    def format_results(self):
        result_string = ""
        results = self.results()
        for result in results:
            result_string += result["name"] + ": " + result["result"] + "\n"
            if result["message"] is not None:
                result_string += result["message"] + "\n\n" 
        return result_string

    def stats(self):
        stats_map = {}
        check_total = len(self.checks)
        stats_map["checks"] = check_total
        stats_map["time"] = self.time
        passed = 0
        failed = 0
        error = 0
        for check in self.checks:
            if check.result == "PASS":
                passed +=1
            if check.result == "FAIL":
                failed +=1            
            if check.result == "ERROR":
                error +=1
        stats_map["passed"] = passed
        stats_map["failed"] = failed
        stats_map["error"] = error
        passed_percent = (passed / check_total) * 100
        failed_percent = (failed / check_total) * 100
        error_percent = (error / check_total) * 100
        stats_map["passed_percent"] = passed_percent
        stats_map["failed_percent"] = failed_percent
        stats_map["error_percent"] = error_percent
        return stats_map

    def format_stats(self):
        stats = self.stats()
        time_string = "Time: " + str(stats["time"]) + "s\n"
        check_string = "Checks: " + str(stats["checks"]) + "\n"
        pass_string = "Pass: " + str(stats["passed"]) + " - (" + str(stats["passed_percent"]) + ")\n"
        fail_string = "Fail: " + str(stats["failed"]) + " - (" + str(stats["failed_percent"]) + ")\n"
        err_string = "Error: " + str(stats["error"]) + " - (" + str(stats["error_percent"]) + ")\n"
        stats_string = time_string + check_string + pass_string + fail_string + err_string
        return stats_string



import time

from ...core_runner import CoreRunner
from .aws_eks_context import AWSEKSContext

# Import AWS EKS Checks
from .checks.service_logging_check import ServiceLoggingCheck
from .checks.service_secrets_check import ServiceSecretsCheck


class AWSEKSRunner(CoreRunner):
    def __init__(self, name):
        start_time = time.time() 

        super().__init__(name)

        # Set AWS EKS related data
        self.cloud = "aws"
        self.resource = "eks"
        self.link = "https://github.com/njgibbon/sek/blob/main/checks/aws/eks"

        # Create AWS EKS Context
        self.context = AWSEKSContext(name)

        # Load AWS EKS Checks into the Runner
        service_logging_check = ServiceLoggingCheck(name, self.context)
        service_secrets_check = ServiceSecretsCheck(name, self.context)
        self.checks.append(service_logging_check)
        self.checks.append(service_secrets_check)

        # Run all Checks
        super().scan()

        time.sleep(1.5)
        self.time = time.time() - start_time
